package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.ExceptionConst;
import org.apache.bcel.classfile.ConstantClass;
import org.apache.bcel.classfile.ConstantFloat;
import org.apache.bcel.classfile.ConstantInteger;
import org.apache.bcel.classfile.ConstantString;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/LDC.class */
public class LDC extends CPInstruction implements PushInstruction, ExceptionThrower {
    /* JADX INFO: Access modifiers changed from: package-private */
    public LDC() {
    }

    public LDC(int index) {
        super((short) 19, index);
        setSize();
    }

    @Override // org.apache.bcel.generic.Instruction
    public void accept(Visitor v) {
        v.visitStackProducer(this);
        v.visitPushInstruction(this);
        v.visitExceptionThrower(this);
        v.visitTypedInstruction(this);
        v.visitCPInstruction(this);
        v.visitLDC(this);
    }

    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        out.writeByte(super.getOpcode());
        if (super.getLength() == 2) {
            out.writeByte(super.getIndex());
        } else {
            out.writeShort(super.getIndex());
        }
    }

    @Override // org.apache.bcel.generic.ExceptionThrower
    public Class<?>[] getExceptions() {
        return ExceptionConst.createExceptions(ExceptionConst.EXCS.EXCS_STRING_RESOLUTION, new Class[0]);
    }

    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.TypedInstruction
    public Type getType(ConstantPoolGen cpg) {
        switch (cpg.getConstantPool().getConstant(super.getIndex()).getTag()) {
            case 3:
                return Type.INT;
            case 4:
                return Type.FLOAT;
            case 5:
            case 6:
            default:
                throw new IllegalArgumentException("Unknown or invalid constant type at " + super.getIndex());
            case 7:
                return Type.CLASS;
            case 8:
                return Type.STRING;
        }
    }

    public Object getValue(ConstantPoolGen cpg) {
        ConstantString constant = cpg.getConstantPool().getConstant(super.getIndex());
        switch (constant.getTag()) {
            case 3:
                return Integer.valueOf(((ConstantInteger) constant).getBytes());
            case 4:
                return Float.valueOf(((ConstantFloat) constant).getBytes());
            case 5:
            case 6:
            default:
                throw new IllegalArgumentException("Unknown or invalid constant type at " + super.getIndex());
            case 7:
                int nameIndex = ((ConstantClass) constant).getNameIndex();
                return new ObjectType(cpg.getConstantPool().getConstant(nameIndex).getBytes());
            case 8:
                int i = constant.getStringIndex();
                return cpg.getConstantPool().getConstant(i).getBytes();
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.Instruction
    public void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        super.setLength(2);
        super.setIndex(bytes.readUnsignedByte());
    }

    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.IndexedInstruction
    public final void setIndex(int index) {
        super.setIndex(index);
        setSize();
    }

    protected final void setSize() {
        if (super.getIndex() <= 255) {
            super.setOpcode((short) 18);
            super.setLength(2);
        } else {
            super.setOpcode((short) 19);
            super.setLength(3);
        }
    }
}
